@@ -145,17 +145,29 @@ def _get_api_version(dyn_client, api_group, kind):
     return res.group_version
 
 
-def _get_client(config_file=None, context=None):
+def get_client(config_file=None, config_dict=None, context=None):
     """
     Get a kubernetes client.
 
+    Pass either config_file or config_dict.
+    If none of them are passed, client will be created from default OS kubeconfig
+    (environment variable or .kube folder).
+
     Args:
         config_file (str): path to a kubeconfig file.
+        config_dict (dict): dict with kubeconfig configuration.
         context (str): name of the context to use.
 
     Returns:
         DynamicClient: a kubernetes client.
     """
+    if config_dict:
+        return DynamicClient(
+            client=kubernetes.config.new_client_from_config_dict(
+                config_dict=config_dict,
+                context=context,
+            )
+        )
     return DynamicClient(
         client=kubernetes.config.new_client_from_config(
             config_file=config_file,
@@ -409,16 +421,6 @@ class Resource:
         if not (self.name or self.yaml_file):
             raise ValueError("name or yaml file is required")
 
-        if not self.client:
-            self.client = _get_client(
-                config_file=self.config_file, context=self.context
-            )
-
-        if not self.api_version:
-            self.api_version = _get_api_version(
-                dyn_client=self.client, api_group=self.api_group, kind=self.kind
-            )
-
         self.teardown = teardown
         self.timeout = timeout
         self.delete_timeout = delete_timeout
@@ -458,6 +460,7 @@ class Resource:
             self.resource_dict.get("metadata", {}).pop("resourceVersion", None)
             self.name = self.resource_dict["metadata"]["name"]
         else:
+            self._set_client_and_api_version()
             self.resource_dict = {
                 "apiVersion": self.api_version,
                 "kind": self.kind,
@@ -578,6 +581,15 @@ class Resource:
 
         return kwargs
 
+    def _set_client_and_api_version(self):
+        if not self.client:
+            self.client = get_client(config_file=self.config_file, context=self.context)
+
+        if not self.api_version:
+            self.api_version = _get_api_version(
+                dyn_client=self.client, api_group=self.api_group, kind=self.kind
+            )
+
     def full_api(self, **kwargs):
         """
         Get resource API
@@ -597,6 +609,8 @@ class Resource:
         Returns:
             Resource: Resource object.
         """
+        self._set_client_and_api_version()
+
         kwargs = self._prepare_singular_name_kwargs(**kwargs)
 
         return self.client.resources.get(
@@ -844,7 +858,7 @@ class Resource:
             generator: Generator of Resources of cls.kind
         """
         if not dyn_client:
-            dyn_client = _get_client(config_file=config_file, context=context)
+            dyn_client = get_client(config_file=config_file, context=context)
 
         def _get():
             _resources = cls._prepare_resources(
@@ -1009,7 +1023,7 @@ class NamespacedResource(Resource):
             generator: Generator of Resources of cls.kind
         """
         if not dyn_client:
-            dyn_client = _get_client(config_file=config_file, context=context)
+            dyn_client = get_client(config_file=config_file, context=context)
 
         _resources = cls._prepare_resources(
             dyn_client=dyn_client, singular_name=singular_name, *args, **kwargs
